# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import events_pb2 as dgt__sdk_dot_protobuf_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_event.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\020client_event_pb2'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_event.proto\x1a\x1d\x64gt_sdk/protobuf/events.proto\"g\n\x1c\x43lientEventsSubscribeRequest\x12)\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x12.EventSubscription\x12\x1c\n\x14last_known_block_ids\x18\x02 \x03(\t\"\xbb\x01\n\x1d\x43lientEventsSubscribeResponse\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.ClientEventsSubscribeResponse.Status\x12\x18\n\x10response_message\x18\x02 \x01(\t\"I\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINVALID_FILTER\x10\x02\x12\x11\n\rUNKNOWN_BLOCK\x10\x03\" \n\x1e\x43lientEventsUnsubscribeRequest\"\x92\x01\n\x1f\x43lientEventsUnsubscribeResponse\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.ClientEventsUnsubscribeResponse.Status\"6\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\"V\n\x16\x43lientEventsGetRequest\x12)\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x12.EventSubscription\x12\x11\n\tblock_ids\x18\x02 \x03(\t\"\xc1\x01\n\x17\x43lientEventsGetResponse\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.ClientEventsGetResponse.Status\x12\x16\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x06.Event\"]\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x12\n\x0eINVALID_FILTER\x10\x03\x12\x11\n\rUNKNOWN_BLOCK\x10\x04\x42+\n\x15sawtooth.sdk.protobufP\x01Z\x10\x63lient_event_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_events__pb2.DESCRIPTOR,])



_CLIENTEVENTSSUBSCRIBERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientEventsSubscribeResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FILTER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=290,
  serialized_end=363,
)
_sym_db.RegisterEnumDescriptor(_CLIENTEVENTSSUBSCRIBERESPONSE_STATUS)

_CLIENTEVENTSUNSUBSCRIBERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientEventsUnsubscribeResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=492,
  serialized_end=546,
)
_sym_db.RegisterEnumDescriptor(_CLIENTEVENTSUNSUBSCRIBERESPONSE_STATUS)

_CLIENTEVENTSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientEventsGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FILTER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=737,
  serialized_end=830,
)
_sym_db.RegisterEnumDescriptor(_CLIENTEVENTSGETRESPONSE_STATUS)


_CLIENTEVENTSSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='ClientEventsSubscribeRequest',
  full_name='ClientEventsSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriptions', full_name='ClientEventsSubscribeRequest.subscriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_known_block_ids', full_name='ClientEventsSubscribeRequest.last_known_block_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=173,
)


_CLIENTEVENTSSUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='ClientEventsSubscribeResponse',
  full_name='ClientEventsSubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientEventsSubscribeResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_message', full_name='ClientEventsSubscribeResponse.response_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTEVENTSSUBSCRIBERESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=363,
)


_CLIENTEVENTSUNSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='ClientEventsUnsubscribeRequest',
  full_name='ClientEventsUnsubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=397,
)


_CLIENTEVENTSUNSUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='ClientEventsUnsubscribeResponse',
  full_name='ClientEventsUnsubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientEventsUnsubscribeResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTEVENTSUNSUBSCRIBERESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=546,
)


_CLIENTEVENTSGETREQUEST = _descriptor.Descriptor(
  name='ClientEventsGetRequest',
  full_name='ClientEventsGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriptions', full_name='ClientEventsGetRequest.subscriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_ids', full_name='ClientEventsGetRequest.block_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=634,
)


_CLIENTEVENTSGETRESPONSE = _descriptor.Descriptor(
  name='ClientEventsGetResponse',
  full_name='ClientEventsGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientEventsGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='ClientEventsGetResponse.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTEVENTSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=830,
)

_CLIENTEVENTSSUBSCRIBEREQUEST.fields_by_name['subscriptions'].message_type = dgt__sdk_dot_protobuf_dot_events__pb2._EVENTSUBSCRIPTION
_CLIENTEVENTSSUBSCRIBERESPONSE.fields_by_name['status'].enum_type = _CLIENTEVENTSSUBSCRIBERESPONSE_STATUS
_CLIENTEVENTSSUBSCRIBERESPONSE_STATUS.containing_type = _CLIENTEVENTSSUBSCRIBERESPONSE
_CLIENTEVENTSUNSUBSCRIBERESPONSE.fields_by_name['status'].enum_type = _CLIENTEVENTSUNSUBSCRIBERESPONSE_STATUS
_CLIENTEVENTSUNSUBSCRIBERESPONSE_STATUS.containing_type = _CLIENTEVENTSUNSUBSCRIBERESPONSE
_CLIENTEVENTSGETREQUEST.fields_by_name['subscriptions'].message_type = dgt__sdk_dot_protobuf_dot_events__pb2._EVENTSUBSCRIPTION
_CLIENTEVENTSGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTEVENTSGETRESPONSE_STATUS
_CLIENTEVENTSGETRESPONSE.fields_by_name['events'].message_type = dgt__sdk_dot_protobuf_dot_events__pb2._EVENT
_CLIENTEVENTSGETRESPONSE_STATUS.containing_type = _CLIENTEVENTSGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientEventsSubscribeRequest'] = _CLIENTEVENTSSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['ClientEventsSubscribeResponse'] = _CLIENTEVENTSSUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['ClientEventsUnsubscribeRequest'] = _CLIENTEVENTSUNSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['ClientEventsUnsubscribeResponse'] = _CLIENTEVENTSUNSUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['ClientEventsGetRequest'] = _CLIENTEVENTSGETREQUEST
DESCRIPTOR.message_types_by_name['ClientEventsGetResponse'] = _CLIENTEVENTSGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientEventsSubscribeRequest = _reflection.GeneratedProtocolMessageType('ClientEventsSubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSSUBSCRIBEREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsSubscribeRequest)
  ))
_sym_db.RegisterMessage(ClientEventsSubscribeRequest)

ClientEventsSubscribeResponse = _reflection.GeneratedProtocolMessageType('ClientEventsSubscribeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSSUBSCRIBERESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsSubscribeResponse)
  ))
_sym_db.RegisterMessage(ClientEventsSubscribeResponse)

ClientEventsUnsubscribeRequest = _reflection.GeneratedProtocolMessageType('ClientEventsUnsubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSUNSUBSCRIBEREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsUnsubscribeRequest)
  ))
_sym_db.RegisterMessage(ClientEventsUnsubscribeRequest)

ClientEventsUnsubscribeResponse = _reflection.GeneratedProtocolMessageType('ClientEventsUnsubscribeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSUNSUBSCRIBERESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsUnsubscribeResponse)
  ))
_sym_db.RegisterMessage(ClientEventsUnsubscribeResponse)

ClientEventsGetRequest = _reflection.GeneratedProtocolMessageType('ClientEventsGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsGetRequest)
  ))
_sym_db.RegisterMessage(ClientEventsGetRequest)

ClientEventsGetResponse = _reflection.GeneratedProtocolMessageType('ClientEventsGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTEVENTSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_event_pb2'
  # @@protoc_insertion_point(class_scope:ClientEventsGetResponse)
  ))
_sym_db.RegisterMessage(ClientEventsGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import transaction_pb2 as dgt__sdk_dot_protobuf_dot_transaction__pb2
from dgt_sdk.protobuf import client_list_control_pb2 as dgt__sdk_dot_protobuf_dot_client__list__control__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_transaction.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\026client_transaction_pb2'),
  serialized_pb=_b('\n)dgt_sdk/protobuf/client_transaction.proto\x1a\"dgt_sdk/protobuf/transaction.proto\x1a*dgt_sdk/protobuf/client_list_control.proto\"\x95\x01\n\x1c\x43lientTransactionListRequest\x12\x0f\n\x07head_id\x18\x01 \x01(\t\x12\x17\n\x0ftransaction_ids\x18\x02 \x03(\t\x12%\n\x06paging\x18\x03 \x01(\x0b\x32\x15.ClientPagingControls\x12$\n\x07sorting\x18\x04 \x03(\x0b\x32\x13.ClientSortControls\"\xce\x02\n\x1d\x43lientTransactionListResponse\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.ClientTransactionListResponse.Status\x12\"\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x0c.Transaction\x12\x0f\n\x07head_id\x18\x03 \x01(\t\x12%\n\x06paging\x18\x04 \x01(\x0b\x32\x15.ClientPagingResponse\"\x99\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\x0b\n\x07NO_ROOT\x10\x04\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x12\n\x0eINVALID_PAGING\x10\x06\x12\x10\n\x0cINVALID_SORT\x10\x07\x12\x0e\n\nINVALID_ID\x10\x08\"5\n\x1b\x43lientTransactionGetRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\"\xd0\x01\n\x1c\x43lientTransactionGetResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ClientTransactionGetResponse.Status\x12!\n\x0btransaction\x18\x02 \x01(\x0b\x32\x0c.Transaction\"W\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x0e\n\nINVALID_ID\x10\x08\x42\x31\n\x15sawtooth.sdk.protobufP\x01Z\x16\x63lient_transaction_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_transaction__pb2.DESCRIPTOR,dgt__sdk_dot_protobuf_dot_client__list__control__pb2.DESCRIPTOR,])



_CLIENTTRANSACTIONLISTRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientTransactionListResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ROOT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PAGING', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SORT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=459,
  serialized_end=612,
)
_sym_db.RegisterEnumDescriptor(_CLIENTTRANSACTIONLISTRESPONSE_STATUS)

_CLIENTTRANSACTIONGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientTransactionGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=4, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=791,
  serialized_end=878,
)
_sym_db.RegisterEnumDescriptor(_CLIENTTRANSACTIONGETRESPONSE_STATUS)


_CLIENTTRANSACTIONLISTREQUEST = _descriptor.Descriptor(
  name='ClientTransactionListRequest',
  full_name='ClientTransactionListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientTransactionListRequest.head_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_ids', full_name='ClientTransactionListRequest.transaction_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientTransactionListRequest.paging', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorting', full_name='ClientTransactionListRequest.sorting', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=275,
)


_CLIENTTRANSACTIONLISTRESPONSE = _descriptor.Descriptor(
  name='ClientTransactionListResponse',
  full_name='ClientTransactionListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientTransactionListResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='ClientTransactionListResponse.transactions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientTransactionListResponse.head_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientTransactionListResponse.paging', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTTRANSACTIONLISTRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=612,
)


_CLIENTTRANSACTIONGETREQUEST = _descriptor.Descriptor(
  name='ClientTransactionGetRequest',
  full_name='ClientTransactionGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='ClientTransactionGetRequest.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=667,
)


_CLIENTTRANSACTIONGETRESPONSE = _descriptor.Descriptor(
  name='ClientTransactionGetResponse',
  full_name='ClientTransactionGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientTransactionGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction', full_name='ClientTransactionGetResponse.transaction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTTRANSACTIONGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=878,
)

_CLIENTTRANSACTIONLISTREQUEST.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGCONTROLS
_CLIENTTRANSACTIONLISTREQUEST.fields_by_name['sorting'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTSORTCONTROLS
_CLIENTTRANSACTIONLISTRESPONSE.fields_by_name['status'].enum_type = _CLIENTTRANSACTIONLISTRESPONSE_STATUS
_CLIENTTRANSACTIONLISTRESPONSE.fields_by_name['transactions'].message_type = dgt__sdk_dot_protobuf_dot_transaction__pb2._TRANSACTION
_CLIENTTRANSACTIONLISTRESPONSE.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGRESPONSE
_CLIENTTRANSACTIONLISTRESPONSE_STATUS.containing_type = _CLIENTTRANSACTIONLISTRESPONSE
_CLIENTTRANSACTIONGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTTRANSACTIONGETRESPONSE_STATUS
_CLIENTTRANSACTIONGETRESPONSE.fields_by_name['transaction'].message_type = dgt__sdk_dot_protobuf_dot_transaction__pb2._TRANSACTION
_CLIENTTRANSACTIONGETRESPONSE_STATUS.containing_type = _CLIENTTRANSACTIONGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientTransactionListRequest'] = _CLIENTTRANSACTIONLISTREQUEST
DESCRIPTOR.message_types_by_name['ClientTransactionListResponse'] = _CLIENTTRANSACTIONLISTRESPONSE
DESCRIPTOR.message_types_by_name['ClientTransactionGetRequest'] = _CLIENTTRANSACTIONGETREQUEST
DESCRIPTOR.message_types_by_name['ClientTransactionGetResponse'] = _CLIENTTRANSACTIONGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientTransactionListRequest = _reflection.GeneratedProtocolMessageType('ClientTransactionListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTRANSACTIONLISTREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_transaction_pb2'
  # @@protoc_insertion_point(class_scope:ClientTransactionListRequest)
  ))
_sym_db.RegisterMessage(ClientTransactionListRequest)

ClientTransactionListResponse = _reflection.GeneratedProtocolMessageType('ClientTransactionListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTRANSACTIONLISTRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_transaction_pb2'
  # @@protoc_insertion_point(class_scope:ClientTransactionListResponse)
  ))
_sym_db.RegisterMessage(ClientTransactionListResponse)

ClientTransactionGetRequest = _reflection.GeneratedProtocolMessageType('ClientTransactionGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTRANSACTIONGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_transaction_pb2'
  # @@protoc_insertion_point(class_scope:ClientTransactionGetRequest)
  ))
_sym_db.RegisterMessage(ClientTransactionGetRequest)

ClientTransactionGetResponse = _reflection.GeneratedProtocolMessageType('ClientTransactionGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTTRANSACTIONGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_transaction_pb2'
  # @@protoc_insertion_point(class_scope:ClientTransactionGetResponse)
  ))
_sym_db.RegisterMessage(ClientTransactionGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -----------------------------------------------------------------------------

import abc
from collections import namedtuple


StartupState = namedtuple(
    'StartupInfo',
    ['chain_head', 'peers', 'local_peer_info','peering_mode'])


class Engine(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def start(self, updates, service, startup_state):
        '''Called after the engine is initialized, when a connection to the
        validator has been established. Notifications from the
        validator are sent along UPDATES. SERVICE is used to send
        requests to the validator.

        Args:
            updates (Queue)
            service (Service)
            startup (StartupInfo)
        '''

    @abc.abstractmethod
    def stop(self):
        '''Called before the engine is dropped in order to give the engine a
        chance to notify peers and clean up.'''

    @abc.abstractproperty
    def version(self):
        '''Get the version of this engine.

        Return:
            str
        '''

    @abc.abstractproperty
    def name(self):
        '''Get the name of the engine, typically the algorithm being
        implemented.

        Return:
            str
        '''



# Copyright  2018 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------

import binascii
import warnings
import datetime

from dgt_signing.core import SigningError
from dgt_signing.core import ParseError

from dgt_signing.core import PrivateKey
from dgt_signing.core import PublicKey
from dgt_signing.core import Context
from dgt_signing.core import X509_COUNTRY_NAME,X509_STATE_OR_PROVINCE_NAME,X509_LOCALITY_NAME,X509_ORGANIZATION_NAME,X509_COMMON_NAME,X509_DNS_NAME, X509_EMAIL_ADDRESS,X509_PSEUDONYM            

from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.serialization import load_der_public_key,load_der_private_key

import logging

# x509
#from cryptography.hazmat.primitives.asymmetric import rsa
from cryptography import x509

from cryptography.x509.oid import NameOID
# ecdsa-sha2-SECP256K1

x509_attr_map = { X509_COUNTRY_NAME           : NameOID.COUNTRY_NAME,
                  X509_STATE_OR_PROVINCE_NAME : NameOID.STATE_OR_PROVINCE_NAME,
                  X509_LOCALITY_NAME          : NameOID.LOCALITY_NAME,
                  X509_ORGANIZATION_NAME      : NameOID.ORGANIZATION_NAME,
                  X509_COMMON_NAME            : NameOID.COMMON_NAME,
                  X509_EMAIL_ADDRESS          : NameOID.EMAIL_ADDRESS,
                  X509_PSEUDONYM              : NameOID.PSEUDONYM    

                  }




def test_asymmetric(data):                                                           
                                                                                     
    ecr = ec.SECP384R1()                                                             
    eck = ec.SECP256K1()                                                             
    private_key = ec.generate_private_key(eck,backend= default_backend())            
    public_key = private_key.public_key()                                            
    signature = private_key.sign(data,ec.ECDSA(hashes.SHA256()))                     
    ret = public_key.verify(signature, data, ec.ECDSA(hashes.SHA256()))              
    print('sign',signature,'ret',ret)                                                
                                                                                     

class OpenCryptoPrivateKey(PrivateKey):
    def __init__(self,ctx, open_private_key=None):
        self._private_key = open_private_key
        self._ctx  = ctx
        self._serialized_private = open_private_key.private_bytes(
            encoding=serialization.Encoding.DER,
            format=serialization.PrivateFormat.TraditionalOpenSSL,
            encryption_algorithm=serialization.NoEncryption()
            )
        logging.info(f"OpenCryptoPrivateKey: priv={self._serialized_private} hex={self.as_hex()}")
    def get_algorithm_name(self):
        return self._ctx.algorithm

    def as_hex(self):
        return binascii.hexlify(self.as_bytes()).decode()

    def as_bytes(self):
        return self._serialized_private

    @property
    def private_key(self):
        return self._private_key




class OpenCryptoPublicKey(PublicKey):
    def __init__(self,ctx, open_public_key=None):
        self._public_key = open_public_key
        self._ctx  = ctx
        self._serialized_public = open_public_key.public_bytes(
            encoding=serialization.Encoding.DER,
            format=serialization.PublicFormat.SubjectPublicKeyInfo
        )
        logging.info(f"OpenCryptoPublicKey: pub={self._serialized_public} hex={self.as_hex()}")
    @property
    def public_key(self):
        return self._public_key

    def get_algorithm_name(self):
        return self._ctx.algorithm

    def as_hex(self):
        return binascii.hexlify(self.as_bytes()).decode()

    def as_bytes(self):
        with warnings.catch_warnings():  # squelch secp256k1 warning
            warnings.simplefilter('ignore')
            return self._serialized_public #serialize()



class OpenCryptoContext(Context):
    def __init__(self,algorithm=None,backend=None):
        self._backend = backend if backend is not None else default_backend()
        self._algorithm = algorithm
        if algorithm == "secp256k1":
            self._ctx  = ec.SECP256K1()  
        elif algorithm == "SECP384R1":
            self._ctx  = ec.SECP384R1() 
        else:
            self._algorithm = "secp256k1"
            self._ctx  = ec.SECP256K1()
        logging.info(f"OpenCryptoContext: CRYPTO_BACK={backend} algorithm={self._algorithm}")

    @property
    def algorithm(self):
        self._algorithm

    def get_algorithm_name(self):
        return self._algorithm

    def new_private_key(self):
        return ec.generate_private_key(self._ctx,backend= self._backend)

    def sign(self, message, priv):
        try:
            #signature = private_key.secp256k1_private_key.ecdsa_sign(message)
            #signature = private_key.secp256k1_private_key.ecdsa_serialize_compact(signature)
            signature = priv.private_key.sign(message,ec.ECDSA(hashes.SHA256()))
            return signature.hex()
        except Exception as e:
            raise SigningError(f'Unable to sign message: {e}')

    def verify(self, signature, message, public):
        try:
            sig_bytes = bytes.fromhex(signature)
            public.public_key.verify(sig_bytes, message, ec.ECDSA(hashes.SHA256()))
            return True
            #sig = public_key.secp256k1_public_key.ecdsa_deserialize_compact(sig_bytes)
            #return public_key.secp256k1_public_key.ecdsa_verify(message, sig)
        except Exception:
            return False

    def pub_from_hex(self,hex_str):
        try:                                                                 
            
            serialized_public = binascii.unhexlify(hex_str)   
            public_key = load_der_public_key(serialized_public,backend= self._backend)                                                                 
            return OpenCryptoPublicKey(self,public_key)                                     
        except Exception as e:                                               
            raise ParseError('Unable to parse public key: {}'.format(e))  
           
    def from_hex(self,hex_str):
        try:                                                                    
            serialized_private = binascii.unhexlify(hex_str) 
            logging.info(f"OpenCryptoContext.from_hex: hex={hex_str} serialized={serialized_private}")
            priv_key = load_der_private_key(serialized_private,None,backend= self._backend)                                 
            return OpenCryptoPrivateKey(self,priv_key)                                       
        except Exception as e:                                                  
            raise ParseError(f'Unable to parse hex={hex_str} private key: {e}')  
         
    def from_wif(self,hex_str):
        raise ParseError(f'Unable to parse hex={hex_str} private key')

    def new_random_private_key(self):
        return OpenCryptoPrivateKey(self,self.new_private_key())

    def new_random(self):              
        return OpenCryptoPrivateKey(self,self.new_private_key())   

    def get_public_key(self, priv):
        return OpenCryptoPublicKey(self,priv.private_key.public_key())

    def create_x509_certificate(self,subject_info,priv,after=None,before=None):
        attribures = []
        key = priv.private_key
        for attr,val in subject_info.items():
            if attr in x509_attr_map:
                rattr = x509_attr_map[attr]
                attribures.append(x509.NameAttribute(rattr,val))

        subject = issuer = x509.Name(attribures)  
        tmnow = datetime.datetime.utcnow()
        valid_before = tmnow if before is None else tmnow + datetime.timedelta(days=before)
        
        cert = x509.CertificateBuilder().subject_name(
                subject
                ).issuer_name(
                    issuer
                ).public_key(
                   key.public_key()
                ).serial_number(
                  x509.random_serial_number()
                ).not_valid_before(
                   valid_before
                )

        if after is not None:
            cert = cert.not_valid_after(
                   # Our certificate will be valid for 10 days
                     valid_before + datetime.timedelta(days=after)
                  )

        if X509_DNS_NAME in subject_info:
            cert = cert.add_extension(
                        x509.SubjectAlternativeName([x509.DNSName(subject_info[X509_DNS_NAME])]),
                        critical=False,
                        )

        # Sign our certificate with our private key
        cert = cert.sign(key, hashes.SHA256(), backend= self._backend)
        cert_pem = cert.public_bytes(serialization.Encoding.PEM)

        logging.info(f"create_x509_certificate: CERT={cert_pem}")
        print(f"create_x509_certificate: CERT={cert_pem}")
        public_key = cert.public_key()                                            
        if isinstance(public_key, ec.EllipticCurvePublicKey):                   
            # Do something EC specific                                            
            logging.info(f"create_x509_certificate: KEY=EllipticCurvePublicKey") 
            print("create_x509_certificate: KEY=EllipticCurvePublicKey") 
        
        return cert_pem 
    
    def load_x509_certificate(self,cert_pem):
        xcert = x509.load_pem_x509_certificate(cert_pem,backend= self._backend)
        #print(f"load_x509_certificate: SERIAL={xcert.serial_number} cert={xcert}")
        return xcert




# Copyright 2016 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------


class _TpResponseError(Exception):
    """Parent class for errors that will be parsed and sent to a validator.

    Args:
        message (str): Standard error message to be logged or sent back
        extended_data (bytes, optional): Byte-encoded data to be parsed later
            by the app developer. Opaque to the validator and Sawtooth.
    """

    def __init__(self, message, extended_data=None):
        super().__init__(message)

        if extended_data is not None and not isinstance(extended_data, bytes):
            raise TypeError("extended_data must be byte-encoded")
        self.extended_data = extended_data


class InvalidTransaction(_TpResponseError):
    """Raised for an Invalid Transaction."""
    pass


class InternalError(_TpResponseError):
    """Raised when an internal error occurs during transaction processing."""
    pass


class AuthorizationException(Exception):
    """Raised when a authorization error occurs."""
    pass


class LocalConfigurationError(Exception):
    """Raised when a log configuraiton error occurs."""
    pass
